@@ -1,3 +1,4 @@
+import { defineMessages, FormattedMessage } from 'react-intl';
 import ImmutablePropTypes from 'react-immutable-proptypes';
 import React from 'react';
 
@@ -7,6 +8,13 @@ import Loader from '../ui/Loader';
 import ProgressBar from '../ui/ProgressBar';
 import StackResourcesTable from './StackResourcesTable';
 
+const messages = defineMessages({
+  resources: {
+    id: 'DeploymentSuccess.resources',
+    defaultMessage: 'Resources'
+  }
+});
+
 export default class DeploymentProgress extends React.Component {
   componentDidMount() {
     this.props.fetchStackResources(this.props.stack);
@@ -24,7 +32,9 @@ export default class DeploymentProgress extends React.Component {
 
   render() {
     const statusMessage = (
-      <strong>{statusMessages[this.props.stack.stack_status]}</strong>
+      <strong>
+        <FormattedMessage {...statusMessages[this.props.stack.stack_status]} />
+      </strong>
     );
 
     return (
@@ -33,7 +43,7 @@ export default class DeploymentProgress extends React.Component {
           <Loader loaded={false} content={statusMessage} inline/>
         </div>
         {this.renderProgressBar()}
-        <h2>Resources</h2>
+        <h2><FormattedMessage {...messages.resources}/></h2>
         <StackResourcesTable isFetchingResources={!this.props.stackResourcesLoaded}
                              resources={this.props.stackResources.reverse()}/>
       </div>
