@@ -21,5 +21,8 @@ export default keyMirror({
   CREATE_PLAN_FAILED: null,
   START_DEPLOYMENT_SUCCESS: null,
   START_DEPLOYMENT_PENDING: null,
-  START_DEPLOYMENT_FAILED: null
+  START_DEPLOYMENT_FAILED: null,
+  EXPORT_PLAN_PENDING: null,
+  EXPORT_PLAN_SUCCESS: null,
+  EXPORT_PLAN_FAILED: null
 });
