@@ -18,16 +18,14 @@ export const getNodesWithMacs = createSelector(
   [getNodes, getPorts], (nodes, ports) =>
     nodes
       .map(node => node
-        .update('portsDetail', filterPorts(ports))
+        .update('portsDetail', List(), filterPorts(ports))
         .update(node => node
           .set('macs', node.get('portsDetail').reduce((str, v) => str + v.address, ''))))
 );
 
 export const getRegisteredNodes = createSelector(
-  getNodesWithMacs, (nodes) => {
-    return nodes.filterNot( node => node.get('provision_state') === 'active' ||
-                                    node.get('maintenance') );
-  }
+  getNodesWithMacs, (nodes) =>
+    nodes.filterNot(node => node.get('provision_state') === 'active' || node.get('maintenance'))
 );
 
 /**
@@ -35,7 +33,7 @@ export const getRegisteredNodes = createSelector(
  */
 export const getProfilesList = createSelector(
   getNodes, nodes => nodes.reduce((profiles, v, k) => {
-    const profile = parseNodeCapabilities(v.getIn(['properties', 'capabilities'])).profile;
+    const profile = getNodeCapabilities(v).profile;
     return profile ? profiles.push(profile) : profiles;
   }, List()).sort()
 );
@@ -48,45 +46,23 @@ export const getAvailableNodeProfiles = createSelector(
     Set.fromKeys(roles).union(profiles).toList().sort()
 );
 
-export const getAvailableNodes = createSelector(
-  getNodesWithMacs, (nodes) => nodes.filter(node => node.get('provision_state') === 'available')
-);
-
 export const getDeployedNodes = createSelector(
-  getNodesWithMacs, (nodes) => {
-    return nodes.filter( node => node.get('provision_state') === 'active' );
-  }
+  getNodesWithMacs, (nodes) =>
+    nodes.filter( node => node.get('provision_state') === 'active' )
 );
 
 export const getMaintenanceNodes = createSelector(
-  getNodesWithMacs, (nodes) => {
-    return nodes.filter( node => node.get('maintenance') );
-  }
-);
-
-export const getUnassignedAvailableNodes = createSelector(
-  getAvailableNodes, (availableNodes) => {
-    return availableNodes.filterNot(
-      node => node.getIn(['properties', 'capabilities'], '').match(/.*profile:([\w\-]+)/)
-    );
-  }
+  getNodesWithMacs, (nodes) =>
+    nodes.filter(node => node.get('maintenance'))
 );
 
 /*
  * booleam, returns true if there are any nodes with operation in progress
  */
 export const getNodesOperationInProgress = createSelector(
-  nodesInProgress, (nodesInProgress) => {
-    return !nodesInProgress.isEmpty();
-  }
+  nodesInProgress, (nodesInProgress) => !nodesInProgress.isEmpty()
 );
 
-export const getAssignedNodes = (availableNodes, roleIdentifier) => {
-  return availableNodes.filter(
-    node => node.getIn(['properties', 'capabilities'], '').includes(`profile:${roleIdentifier}`)
-  );
-};
-
 /**
  * Helper function to convert list of port uuids into map of actual ports
  * @param ports - Map of ports to filter on
@@ -94,3 +70,11 @@ export const getAssignedNodes = (availableNodes, roleIdentifier) => {
  */
 const filterPorts = (ports) =>
   portUUIDs => ports.filter((p, k) => portUUIDs.includes(k));
+
+/**
+ * Helper function to get node capabilities object
+ * @param node
+ * @returns capabilities object
+ */
+export const getNodeCapabilities = (node) =>
+  parseNodeCapabilities(node.getIn(['properties', 'capabilities'], ''));
